@@ -2,7 +2,7 @@
 using System;
 using System.IO;
 using System.Collections;
-using Mono.Posix;
+using Mono.Unix;
 
 namespace Tomboy
 {
@@ -16,12 +16,6 @@ namespace Tomboy
 		PluginManager plugin_mgr;
 		TrieController trie_controller;
 
-		public NoteManager () : 
-			this (Path.Combine (Environment.GetEnvironmentVariable ("HOME"), 
-					    ".tomboy")) 
-		{
-		}
-
 		public NoteManager (string directory) : 
 			this (directory, Path.Combine (directory, "Backup")) 
 		{
@@ -29,56 +23,80 @@ namespace Tomboy
 
 		public NoteManager (string directory, string backup_directory) 
 		{
+			Logger.Log ("NoteManager created with note path \"{0}\".", directory);
+
 			notes_dir = directory;
 			backup_dir = backup_directory;
 			notes = new ArrayList ();
 
-			bool first_run = !Directory.Exists (notes_dir);
-			if (first_run) {
-				// First run. Create storage directory.
-				Directory.CreateDirectory (notes_dir);
-			}
+			bool first_run = FirstRun ();
+			CreateNotesDir ();
 
-			// Create & populate the Plugins dir
-			string plugins_dir = Path.Combine (notes_dir, "Plugins");
-			PluginManager.CreatePluginsDir (plugins_dir);
-
-			plugin_mgr = new PluginManager (plugins_dir);
-			trie_controller = new TrieController (this);
+			plugin_mgr = CreatePluginManager ();
+			trie_controller = CreateTrieController ();
 
 			if (first_run) {
 				// First run. Create "Start Here" note.
 				CreateStartNote ();
 			} else {
-				string [] files = Directory.GetFiles (notes_dir, "*.note");
-
-				foreach (string file_path in files) {
-					Note note = Note.Load (file_path, this);
-					if (note != null) {
-						note.Renamed += OnNoteRename;
-						notes.Add (note);
-					}
-				}
-
-				// Update the trie so plugins can access it, if they want.
-				trie_controller.Update ();
-
-				// Load all the plugins for our notes.
-				foreach (Note note in notes) {
-					plugin_mgr.LoadPluginsForNote (note);
-				}
+				LoadNotes ();
 			}
 
 			Tomboy.ExitingEvent += OnExitingEvent;
 		}
 
+		// Create & populate the Plugins dir. For overriding in test
+		// methods.
+		protected virtual PluginManager CreatePluginManager ()
+		{
+			string tomboy_dir = 
+				Path.Combine (Environment.GetEnvironmentVariable ("HOME"), 
+					      ".tomboy");
+			string plugins_dir = Path.Combine (tomboy_dir, "Plugins");
+			PluginManager.CreatePluginsDir (plugins_dir);
+
+			return new PluginManager (plugins_dir);
+		}
+
+		// Create the TrieController. For overriding in test methods.
+		protected virtual TrieController CreateTrieController ()
+		{
+			return new TrieController (this);
+		}
+
+		// For overriding in test methods.
+		protected virtual bool DirectoryExists (string directory)
+		{
+			return Directory.Exists (directory);
+		}
+
+		// For overriding in test methods.
+		protected virtual DirectoryInfo CreateDirectory (string directory)
+		{
+			return Directory.CreateDirectory (directory);
+		}
+
+		protected virtual bool FirstRun ()
+		{
+			return !DirectoryExists (notes_dir);
+		}
+
+		// Create the notes directory if it doesn't exist yet.
+		void CreateNotesDir ()
+		{
+			if (!DirectoryExists (notes_dir)) {
+				// First run. Create storage directory.
+				CreateDirectory (notes_dir);
+			}
+		}
+
 		void OnNoteRename (Note note, string old_title)
 		{
 			if (NoteRenamed != null)
 				NoteRenamed (note, old_title);
 		}
 
-		void CreateStartNote () 
+		protected virtual void CreateStartNote () 
 		{
 			string content = 
 				string.Format ("<note-content>" +
@@ -103,9 +121,36 @@ namespace Tomboy
 			}
 		}
 
+		protected virtual void LoadNotes ()
+		{
+			string [] files = Directory.GetFiles (notes_dir, "*.note");
+
+			foreach (string file_path in files) {
+				try {
+					Note note = Note.Load (file_path, this);
+					if (note != null) {
+						note.Renamed += OnNoteRename;
+						notes.Add (note);
+					}
+				} catch (System.Xml.XmlException e) {
+					Logger.Log ("Error parsing note XML, skipping \"{0}\": {1}",
+						    file_path,
+						    e.Message);
+				}
+			}
+
+			// Update the trie so plugins can access it, if they want.
+			trie_controller.Update ();
+
+			// Load all the plugins for our notes.
+			foreach (Note note in notes) {
+				plugin_mgr.LoadPluginsForNote (note);
+			}
+		}
+
 		void OnExitingEvent (object sender, EventArgs args)
 		{
-			Console.WriteLine ("Saving unsaved notes...");
+			Logger.Log ("Saving unsaved notes...");
 
 			foreach (Note note in notes) {
 				note.Save ();
@@ -133,7 +178,7 @@ namespace Tomboy
 			notes.Remove (note);
 			note.Delete ();
 
-			Console.WriteLine ("Deleting note '{0}'.", note.Title);
+			Logger.Log ("Deleting note '{0}'.", note.Title);
 
 			if (NoteDeleted != null)
 				NoteDeleted (this, note);
@@ -229,7 +274,7 @@ namespace Tomboy
 
 			string filename = MakeNewFileName ();
 
-			Note new_note = new Note (title, filename, this);
+			Note new_note = Note.CreateNewNote (title, filename, this);
 			new_note.XmlContent = xml_content;
 			new_note.Renamed += OnNoteRename;
 
@@ -307,7 +352,7 @@ namespace Tomboy
 		public event NoteRenameHandler NoteRenamed;
 	}
 
-	class TrieController
+	public class TrieController
 	{
 		TrieTree title_trie;
 		NoteManager manager;
