@@ -4,7 +4,7 @@ using System.Collections;
 using System.IO;
 using System.Runtime.InteropServices;
 using System.Text.RegularExpressions;
-using Mono.Posix;
+using Mono.Unix;
 
 namespace Tomboy
 {
@@ -218,47 +218,22 @@ namespace Tomboy
 			}
 		}
 
-		// To unset GtkSpell's tag Foreground correctly we need to call
-		// SetProperty, which is a protected member.
-		class OldGtkSpellFixup : Gtk.TextTag
-		{
-			public OldGtkSpellFixup (IntPtr raw)
-				: base (raw)
-			{
-			}
-
-			public void Fixup ()
-			{
-				SetProperty ("foreground_gdk", new GLib.Value (Gdk.Color.Zero));
-
-				// Force the value to 4 since error underlining
-				// isn't mapped in Gtk# yet.
-				Underline = (Pango.Underline) 4;
-			}
-		}
-
-		// NOTE: Older versions of GtkSpell before 2.0.6 use red
-		// foreground color and a single underline.  This conflicts with
-		// internal note links.  So fix it up to unset foreground and
-		// use the "error" underline.
-		void FixupOldGtkSpell ()
-		{
-#if OLD_GTKSPELL
-			Gtk.TextTag misspell = Note.TagTable.Lookup ("gtkspell-misspelled");
-			if (misspell != null) {
-				OldGtkSpellFixup hack = new OldGtkSpellFixup (misspell.Handle);
-				hack.Fixup ();
-			}
-#endif
-		}
-
 		void Attach ()
 		{
+			// Make sure we add this tag before attaching, so
+			// gtkspell will use our version.
+			if (Note.TagTable.Lookup ("gtkspell-misspelled") == null) {
+				NoteTag tag = new NoteTag ("gtkspell-misspelled");
+				tag.CanSerialize = false;
+				tag.CanSpellCheck = true;
+				tag.Underline = Pango.Underline.Error;
+				Note.TagTable.Add (tag);
+			}
+
 			if (obj_ptr == IntPtr.Zero) {
 				obj_ptr = gtkspell_new_attach (Window.Editor.Handle, 
 							       null, 
 							       IntPtr.Zero);
-				FixupOldGtkSpell ();
 			}
 		}
 
@@ -289,7 +264,7 @@ namespace Tomboy
 			if (args.Tag.Name == "gtkspell-misspelled") {
 				// Remove misspelled tag for links & title
 				foreach (Gtk.TextTag tag in args.StartChar.Tags) {
-					if (tag != args.Tag && 
+					if (tag != args.Tag &&
 					    !NoteTagTable.TagIsSpellCheckable (tag)) {
 						remove = true;
 						break;
@@ -394,7 +369,7 @@ namespace Tomboy
 		void OpenUrl (string url) 
 		{
 			if (url != string.Empty) {
-				Console.WriteLine ("Opening url '{0}'...", url);
+				Logger.Log ("Opening url '{0}'...", url);
 				Gnome.Url.Show (url);
 			}
 		}
@@ -442,12 +417,12 @@ namespace Tomboy
 			for (Match match = regex.Match (start.GetText (end)); 
 			     match.Success; 
 			     match = match.NextMatch ()) {
-				Group group = match.Groups [1];
+				System.Text.RegularExpressions.Group group = match.Groups [1];
 
 				/*
-				Console.WriteLine("Highlighting url: '{0}' at offset {1}",
-						  group,
-						  group.Index);
+				Logger.Log ("Highlighting url: '{0}' at offset {1}",
+					    group,
+					    group.Index);
 				*/
 
 				Gtk.TextIter start_cpy = start;
@@ -543,7 +518,7 @@ namespace Tomboy
 			string url = GetUrl (start, end);
 
 			Gtk.Clipboard clip = Window.Editor.GetClipboard (Gdk.Selection.Clipboard);
-			clip.SetText (url);
+			clip.Text = url;
 		}
 	}
 
@@ -657,12 +632,15 @@ namespace Tomboy
 				if (range.Text.ToLower () != old_title_lower)
 					continue;
 
-				Console.WriteLine ("Replacing '{0}' with '{0}'", 
-						   range.Text, 
-						   renamed.Title);
+				Logger.Log ("Replacing '{0}' with '{0}'", 
+					    range.Text, 
+					    renamed.Title);
 
-				Buffer.Delete (range.Start, range.End);
-				Buffer.InsertWithTags (range.Start, renamed.Title, link_tag);
+				Gtk.TextIter start_iter = range.Start;
+				Gtk.TextIter end_iter = range.Start;
+				Buffer.Delete (ref start_iter, ref end_iter);
+				start_iter = range.Start;
+				Buffer.InsertWithTags (ref start_iter, renamed.Title, link_tag);
 			}
 		}
 
@@ -682,10 +660,10 @@ namespace Tomboy
 			Gtk.TextIter title_end = start;
 			title_end.ForwardChars (hit.End);
 			
-			Console.WriteLine ("Matching Note title '{0}' at {1}-{2}...", 
-					   hit.Key,
-					   hit.Start,
-					   hit.End);
+			Logger.Log ("Matching Note title '{0}' at {1}-{2}...", 
+				    hit.Key,
+				    hit.Start,
+				    hit.End);
 
 			Buffer.RemoveTag (broken_link_tag, title_start, title_end);
 			Buffer.ApplyTag (link_tag, title_start, title_end);
@@ -761,7 +739,7 @@ namespace Tomboy
 			Note link = Manager.Find (link_name);
 
 			if (link == null) {
-				Console.WriteLine ("Creating note '{0}'...", link_name);
+				Logger.Log ("Creating note '{0}'...", link_name);
 				try {
 				    link = Manager.Create (link_name);
 				} catch (Exception e) {
@@ -770,7 +748,7 @@ namespace Tomboy
 			}
 
 			if (link != null && link != this.Note) {
-				Console.WriteLine ("Opening note '{0}' on click...", link_name);
+				Logger.Log ("Opening note '{0}' on click...", link_name);
 				link.Window.Present ();
 				return true;
 			}
@@ -860,14 +838,14 @@ namespace Tomboy
 			for (Match match = regex.Match (start.GetText (end)); 
 			     match.Success; 
 			     match = match.NextMatch ()) {
-				Group group = match.Groups [1];
+				System.Text.RegularExpressions.Group group = match.Groups [1];
 
 				if (IsPatronymicName (group.ToString ()))
 					continue;
 
-				Console.WriteLine("Highlighting wikiword: '{0}' at offset {1}",
-						  group,
-						  group.Index);
+				Logger.Log ("Highlighting wikiword: '{0}' at offset {1}",
+					    group,
+					    group.Index);
 
 				Gtk.TextIter start_cpy = start;
 				start_cpy.ForwardChars (group.Index);
